import{v as n,Q as l,aa as c,c as u,y as h,E as f,l as w,K as a,L as b}from"./index-96a89f99.js";import{_ as d}from"./ItemsListing.vue_vue_type_style_index_0_lang-100045ef.js";import"./ListviewItem-773c5bab.js";import"./VBadge-bbd5dd5d.js";import"./ListItem-0334be0a.js";import"./forwardRefs-d1b36928.js";import"./VMenu-48d1df5c.js";import"./VCheckboxBtn-b5a7dcd4.js";import"./VSlideGroup-9d54be14.js";import"./VCard-e4d98c58.js";import"./VCardText-e8638424.js";import"./VTooltip-28444823.js";import"./PanelviewItem.vue_vue_type_style_index_0_lang-694ef246.js";import"./contextmenu-c07cf085.js";import"./Alert-d6ed854e.js";import"./Container-0be9c84f.js";/* empty css              */import"./VToolbar-23122cac.js";import"./VTextField-20c6a6f8.js";import"./VVirtualScroll-a42cd261.js";const A=n({__name:"BrowseView",props:{path:{}},setup(s){const t=s,{t:o}=l();c();const p=u(()=>!t.path||t.path=="root"?o("browse"):a("bp6")?o("browse")+" | "+t.path:a("bp3")?t.path:o("browse")),i=async function(e){const r=[];return await b.browse(t.path,m=>{r.push(...m)}),r};return(e,r)=>(h(),f("section",null,[w(d,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":i,"sort-keys":["original","name","name_desc"],title:p.value,path:e.path,"allow-key-hooks":!0},null,8,["title","path"])]))}});export{A as default};
