import{_ as u}from"./ItemsListing.vue_vue_type_style_index_0_lang-100045ef.js";import{_ as f,a as v}from"./ProviderDetails.vue_vue_type_script_setup_true_lang-fb6f0375.js";import{v as _,r as h,w as y,y as a,E as w,l as V,z as m,I as n,B as k,L as s,am as g}from"./index-96a89f99.js";import"./ListviewItem-773c5bab.js";import"./VBadge-bbd5dd5d.js";import"./ListItem-0334be0a.js";import"./forwardRefs-d1b36928.js";import"./VMenu-48d1df5c.js";import"./VCheckboxBtn-b5a7dcd4.js";import"./VSlideGroup-9d54be14.js";import"./VCard-e4d98c58.js";import"./VCardText-e8638424.js";import"./VTooltip-28444823.js";import"./PanelviewItem.vue_vue_type_style_index_0_lang-694ef246.js";import"./contextmenu-c07cf085.js";import"./Alert-d6ed854e.js";import"./Container-0be9c84f.js";/* empty css              */import"./VToolbar-23122cac.js";import"./VTextField-20c6a6f8.js";import"./VVirtualScroll-a42cd261.js";import"./layout-adb5f1c5.js";import"./VDialog-1db6dbeb.js";const I=k("br",null,null,-1),T=_({__name:"RadioDetails",props:{itemId:{},provider:{}},setup(p){const t=p,e=h(),l=async function(){e.value=await s.getRadio(t.itemId,t.provider)};y(()=>t.itemId,i=>{i&&l()},{immediate:!0});const d=async function(i){const o=[];if(t.provider=="library"){const r=await s.getRadioVersions(t.itemId,t.provider);o.push(...r)}for(const r of g(e.value)){const c=await s.getRadioVersions(r.item_id,r.provider_instance);o.push(...c)}return o};return(i,o)=>(a(),w("section",null,[V(f,{item:e.value},null,8,["item"]),e.value?(a(),m(u,{key:0,itemtype:"radioversions","parent-item":e.value,"show-provider":!0,"show-favorites-only-filter":!1,"show-library":!1,"show-radio-number":!1,"show-duration":!1,"load-items":d,"sort-keys":["provider","sort_name"],title:i.$t("other_versions"),"hide-on-empty":!0,checksum:i.provider+i.itemId},null,8,["parent-item","title","checksum"])):n("",!0),I,e.value?(a(),m(v,{key:1,"item-details":e.value},null,8,["item-details"])):n("",!0)]))}});export{T as default};
